AGW Logo

svn SVN Revision 69347 For ultimatelistctrl

This file contains the SVN revision history for ultimatelistctrl, at revision 69347.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 11-Dec-2009 11:51:15 UTC
  • Committer: AG
  • File Size: 457502 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

UltimateListCtrl: close ticket #11864.


svn_diff Diff To Previous Version (69087)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2011/09/14 19:50:15     69087
+++ wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2011/10/09 18:54:23     69347
@@ -3,7 +3,7 @@
# Inspired by and heavily based on the wxWidgets C++ generic version of wxListCtrl.
#
# Andrea Gavana, @ 08 May 2009
# Latest Revision: 14 Sep 2011, 21.00 GMT
#
#
# TODO List
@@ -225,7 +225,7 @@

UltimateListCtrl is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 17 Aug 2011, 15.00 GMT
+Latest Revision: Andrea Gavana @ 09 Oct 2011, 21.00 GMT

Version 0.8

@@ -6443,7 +6443,7 @@
Called by L{UltimateListCtrl.OnSize} when the window is resized.
"""

-        if not self: # Avoid PyDeadObjectError's on Mac
+        if not self: # Avoid PyDeadObjectErrors on Mac
return

if self._resizeColumn == -1:
@@ -6469,7 +6469,7 @@

totColWidth = 0 # Width of all columns except last one.
for col in range(numCols):
-            if col != (resizeCol):
+            if col != (resizeCol) and self.IsColumnShown(col):
totColWidth = totColWidth + self.GetColumnWidth(col)

resizeColWidth = self.GetColumnWidth(resizeCol)
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 08 May 2009
-# Latest Revision: 14 Sep 2011, 21.00 GMT
+# Latest Revision: 09 Oct 2011, 21.00 GMT
#
#
Tree